@@ -1,51 +1,65 @@
-# $Id: Coverage.pm 900 2008-08-03 02:24:08Z gene $
+# $Id: Coverage.pm 902 2008-08-03 06:45:35Z gene $
 
 package Chess::Coverage;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use strict;
 use warnings;
-use Carp;
 use base 'Chess::Rep';
 
 sub coverage {
     my $self = shift;
+
     my %cover = ();
+
     my %name = (
-        p => 'pawn',
-        n => 'knight',
-        b => 'bishop',
-        r => 'rook',
-        q => 'queen',
-        k => 'king',
+        0x01 => 'black pawn',
+        0x02 => 'black knight',
+        0x04 => 'black king',
+        0x08 => 'black bishop',
+        0x10 => 'black rook',
+        0x20 => 'black queen',
+        0x81 => 'white pawn',
+        0x82 => 'white knight',
+        0x84 => 'white king',
+        0x88 => 'white bishop',
+        0x90 => 'white rook',
+        0xA0 => 'white queen',
     );
 
     for my $row (0 .. 7) {
         for my $col (0 .. 7) {
             my $i = Chess::Rep::get_index($row, $col);
             my $p = $name{ $self->get_piece_at($row, $col) } || '';
-            my $x = $self->piece_color($i);
             my $f = Chess::Rep::get_field_id($i);
-            
+
             $cover{$f}{index} = $i;
-            $cover{$f}{occupant} = ($x ? 'black' : 'white') . " $p" if $p;
-            
-            my $moves = $self->_get_allowed_moves($i) if $p;
-            if ($moves && @$moves) {
+
+            my $moves = [];
+
+            if ($p) {
+                $cover{$f}{occupant} = $p;
+                $moves = $self->_get_allowed_moves($i);
+            }
+
+            if (@$moves) {
                 @$moves = map { Chess::Rep::get_field_id($_) } @$moves;
                 $cover{$f}{move} = $moves;
-            }   
-            
-            for my $color (0, 1) {
-                if($self->is_attacked($i, $color)) {
-                    $cover{$f}{ $x == $color ? 'protected' : 'threatened' } = 1;
-                }   
-            }   
-        }   
+            }
+
+            for my $color (0, 0x80) {
+                if($p && $self->is_attacked($i, $color)) {
+                    my $c = $self->piece_color($i);
+                    $cover{$f}{ $c == $color ? 'protected' : 'threatened' } = 1;;
+                }
+            }
+        }
     }
 
     return \%cover;
 }
 
+1;
+
 __END__
 
 =head1 NAME
@@ -57,7 +71,6 @@ Chess::Coverage - Expose chess ply potential energy
   use Chess::Coverage;
   $g = Chess::Coverage->new();
   $c = $g->coverage();
-  use Data::Dumper; $Data::Dumper::Sortkeys=1; die Dumper($c);
 
 =head1 DESCRTIPTION
 
@@ -94,7 +107,7 @@ Return a data structure, keyed on board position, showing
 
 Get C<Chess::Rep> patched to return the indices of the attackers.
 
-Produce an image of the coverage.
+Produce images and animations of the coverage.
 
 =head1 SEE ALSO
 
